/*

    File:     add_a_color.c

    Ref. No:  design.io.graphics.x.0

    Author:   James Garacci

    Date:     JAN-11-1994

    Purpose:

	The purpose of this module is to add a color to the current color
	palette.

    Usage:

	This module can be invoked as follows:

		pixel = add_a_color (widget
                                    ,color);

    Input Parameters:

	widget = a structure of type Widget requesting use of the color to be 
                 added.

	color = a pointer to the structure of type XColor where the information
		about the color to be added is stored.

    Output Parameters:

	pixel = an unsigned long int that represents the pixel number of the
                color received or allocated.

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <X11/Xlib.h>
#include <Mrm/MrmAppl.h>

/*  Functions Referenced:

	store_color

**  System Calls:

	DefaultColormapOfScreen
	DefaultVisualOfScreen
	printf
	XAllocColor
        XAllocColorCells
	XtDisplay
	XtScreen

**  Constant Definitions: **

        DoBlue - used to specify that the blue component of a XColor
                 structure should be modified.

        DoGreen - used to specify that the green component of a XColor
                  structure should be modified.

        DoRed - used to specify that the red component of a XColor
                structure should be modified.

**  Macro Definitions: **

	None

**  External Variables: **

	None

**  Pseudo Code:

  Set the red, green, and blue components of the color to be allocated equal to
     the specified color
  Set the DoRed, DoGreen, and DoBlue flags to indicate that these components
     are to be used
  Attempt to allocate the color
  If ( the attempt failed ) then
    Attempt to allocate a color cell in the default colormap to store the color
    If ( the attempt was successful ) then
      Store the color into the default colormap
    End If
  End If
  Return the pixel value and control to the calling module

    Code:  */

unsigned long add_a_color (Widget  widget
                          ,XColor *color)
{
   XColor        NewRGBcolor;
   unsigned long plane_mask;

   NewRGBcolor.pixel = 0;
   NewRGBcolor.red = color->red;
   NewRGBcolor.green = color->green;
   NewRGBcolor.blue = color->blue;
   NewRGBcolor.flags = DoRed | DoGreen | DoBlue;
   if (!XAllocColor (XtDisplay(widget)
                    ,DefaultColormapOfScreen(XtScreen(widget))
                    ,&NewRGBcolor))
   {
      if (XAllocColorCells (XtDisplay(widget)
                           ,DefaultColormapOfScreen(XtScreen(widget))
                           ,False
                           ,&plane_mask
                           ,0
                           ,&(NewRGBcolor.pixel)
                           ,1))
/* 
   XStoreColor (XtDisplay(widget)
               ,DefaultColormapOfScreen(XtScreen(widget))
               ,&NewRGBcolor);
*/

         store_color (XtDisplay(widget)
                     ,DefaultVisualOfScreen(XtScreen(widget))
                     ,DefaultColormapOfScreen(XtScreen(widget))
                     ,&NewRGBcolor);
   }
   return NewRGBcolor.pixel;
}
