/*

    File:     breakout.c

    Ref. No:  breakout.0

    Author:   James Garacci

    Date:     5-APR-1995

    Purpose:

	The purpose of this module is to initialize the breakout game.

    Usage:

	This module can be invoked as follows:

		breakout

    Input Parameters:

	None

    Output Parameters:

	None

    Side Effects:

	None

    Include Files: */

#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include <Mrm/MrmAppl.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/X.h>
#include "motif.h"
#include "motif.var"
#include "dll.h"
#include "breakout.h"
#include "breakout.var"

/*  Functions Referenced:

	None

**  X Toolkit Calls:

	XtAppInitialize
	XtAppMainLoop
	XtManageChild
	XtRealizeWidget
	XtVaSetValues

**  Mrm Calls:

	MrmFetchWidget
	MrmInitialize
	MrmOpenHierarchy
	MrmRegisterNames

**  System Calls:

	printf
	exit

**  Constant Definitions: **

	None

**  Macro Definitions: **

	None

**  External Variables: **

	wid_top_level
	main_app_context
	uid_file_num
	uid_file_names
	s_MrmHierarchy
	reg_vec
	reg_num
	wid_main
	widget_class
	app_title_name
	app_icon_name

**  Pseudo Code:

  Initialize the Motif resource manager
  Initialize the Application, getting the application context and the top level
      widget.
  Attempt to open the hierarchy of the program
  If(the status of the attempt to open the hierarchy is not MrmSUCCESS) then
    Output an error message
    Terminate the program
  EndIf
  Attempt to register the names of the call back modules
  If(the status of the operation is not MrmSUCCESS) then
    Output an error message
    Terminate the program
  EndIf
  Attempt to fetch the main widget
  If(the status of the attempt to fetch the main widget is not MrmSUCCESS) then
    Output an error message
    Terminate the program
  EndIf
  Set the title and icon name of the main window
  Begin management of the main window
  Realize the top level widget (Display it on the screen)
  Execute the main loop of the application program
  Return control to the command prompt

    Code:  */

void main (int    argc
          ,char **argv)
{
   Cardinal mrm_status;
   Widget   dialog;

   MrmInitialize ();

   wid_top_level = XtAppInitialize (&main_app_context,
                                    "BREAKOUT",
                                    (XrmOptionDescList) NULL,
                                    0,
                                    &argc,
                                    (String *) argv,
                                    (String *) NULL,
                                    (ArgList) NULL,
                                    0);

   mrm_status = MrmOpenHierarchy (uid_file_num,
                                  uid_file_names,
                                  (MrmOsOpenParamPtr *) NULL,
                                  &s_MrmHierarchy);

   if (mrm_status != MrmSUCCESS)
   {
      printf ("Can't open heirarchy.");
      exit (0);
   }
 
   mrm_status = MrmRegisterNames (reg_vec, reg_num);

   if (mrm_status != MrmSUCCESS)
   {
      printf ("Can't register callback routine.");
      exit (0);
   }
 
   mrm_status = MrmFetchWidget (s_MrmHierarchy,
                                "breakout_main",
                                wid_top_level,
                                &wid_main,
                                &widget_class);
   if (mrm_status != MrmSUCCESS)
   {
      printf ("Can't fetch main widget.");
      exit (0);
   }

   popup_dialog("main_dialog",0,True);

   dialog = retrieve_widget_id ("display_area",0);

   XtAddEventHandler (dialog
                     ,(EventMask) Button1MotionMask
                     ,False
                     ,move_paddle
                     ,(XtPointer) NULL);

   XtAppMainLoop (main_app_context);
}
