/*

    File:     cb_help.c

    Ref. No:  callback.8

    Author:   James Garacci

    Date:     MAR-11-1995

    Purpose:

	The purpose of this module is to log a player out of a network game.

    Usage:

	This module can be invoked as follows:

		cb_help (widget
                        ,tag
                        ,callback_data);

    Input Parameters:

        widget = a structure of type Widget where the data pertaining to the
                 widget that invoked the callback is stored.

        tag_string = a structure of type String used to indicate how the Widget
                     is to be stored.  Currently, only one method of storage is
                     supported.

        callback_data = a pointer to a structure of type XmAnyCallbackStruct
                        where the data pertaining to the action that caused the
                        callback to be invoked is stored.

    Output Parameters:

	None

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <string.h>
#include <Mrm/MrmAppl.h>

/*  Functions Referenced:

	popup_dialog
	retrieve_widget_id

**  System Calls:

	fclose
	fgets
	sprintf
	strcpy
	fopen
	XtUnmanageChild

**  Constant Definitions: **

	True

**  Macro Definitions: **

	None

**  External Variables: **

	None

**  Pseudo Code:

  If ( the tag parameter is from the help menu ) then
    Open the appropriate Help text file
    Do For ( each line in the text file )
      Read the line of text
      Store the line of text into the Scrollable Text Area
    End Do For
    Close the Help text file
    Popup the help dialog box
  Else
    If ( the tag parameter is from the help dialog ) then
      Hide the Help dialog box
    End If    
  End If
  Return control to the calling module

    Code:  */

Widget retrieve_widget_id (String widnam
                          ,int wididx);

char *help_files [2] = { "data/breakout.hlp"
                       , "data/help.hlp" };

void cb_help (Widget w
             ,int *tag
             ,XmAnyCallbackStruct *callback_data)
{
   Arg   argument;
   FILE *help_file;
   int   string_size
     ,   text_string_size;
   char *text_string;
   char *temp_string;
   char *text_buffer;
   String old_help_text
        , new_help_text = (String) NULL;
   Widget widget;

   if ( *tag != 0 )
   {
      if (*tag > 0 && *tag < 3)
      {
         text_buffer = (char *) malloc (sizeof (char) * 132);
         text_string_size = 0;
         help_file = fopen (help_files[*tag - 1], "r");
         if (help_file == NULL)
            printf ("(ERROR) Help file couldn't be opened\n");
         while (fgets (text_buffer, 132, help_file) != NULL)
         {
            if (text_string_size)
            {
               temp_string = (char *) malloc (sizeof (char) * text_string_size);
               strcpy (temp_string, text_string);
            }
            string_size = strlen (text_buffer);
            if (text_string_size)
            {
               text_string_size += string_size;
               text_string = (char *) malloc (sizeof (char) * text_string_size);
               strcpy (text_string, temp_string);
               free (temp_string);
               strcat (text_string, text_buffer);
            }
            else
            {
               text_string_size += string_size;
               text_string = (char *) malloc (sizeof (char) * text_string_size);
               strcpy (text_string, text_buffer);
            }
         }
         new_help_text = (String) text_string;
         popup_dialog ("help_dialog", 0 , True);
         widget = retrieve_widget_id ("help_text", 0);
         old_help_text = (String) XmTextGetString (widget);
         if (text_string)
         {
            if (strcmp ((char *) text_string, (char *) old_help_text))
            {
               XmTextSetString (widget
                               ,new_help_text);
            }
         }
         XtFree (old_help_text);
         free (text_string);
      }
   }
   else
   {
     if ( *tag == 0 )
       XtUnmanageChild(retrieve_widget_id("help_dialog", 0));
   }      
}
