/*

    File:     file_load_level.c

    Ref. No:  breakout.6

    Author:   James Garacci

    Date:     20-APR-1995

    Purpose:

	The purpose of this module is to load a level from the specified file.

    Usage:

	This module can be invoked as follows:

		int file_load_level (file_name
                                    ,&list);

    Input Parameters:

	file_name = an array of characters used to specify the name of the file
                    where the level to be loaded is located.

	list = a pointer to a double linked list to hold the bricks.

    Output Parameters:

	(int) = an integer used to indicate the status of the operation.
		Valid values for return are 0 if an error occurred, or non-zero
		to indicate the number of removable bricks.

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include <Mrm/MrmAppl.h>
#include "motif.h"
#include "motif.ext"
#include "dll.h"
#include "breakout.h"
#include "breakout.ext"

/*  Functions Referenced:

	None

**  System Calls:

	exit

**  Constant Definitions: **

	None

**  External Variables: **

	None

**  Pseudo Code:

  Attempt to open the file for read access
  If ( the attempt fails ) then
    Return a 0 to the calling module
  End If
  Return a status of 1 to the calling module

    Code:  */

int file_load_level (char *file_name
                    ,Object_Node **list)
{
   Object_Node *new_brick;
   int column
     , row
     , max_row;
   char file_buffer [132];
   char brick_type;
   FILE *file;
   int bricks;
   
   if ((file = fopen (file_name, "r")) == NULL)
   {
      return 0;
   }
   fgets (file_buffer, 132, file);
   max_row = atoi (file_buffer);
   bricks = 0;
   *list = (Object_Node *) init_headnode ();
   for ( row = 0
       ; row < max_row
       ; row++)
   {
      fgets (file_buffer, 132, file);
      for ( column = 0
          ; column < 10
          ; column++)
      {
         brick_type = file_buffer[column];
         if ( (brick_type > '0' && brick_type <= '9')
            || brick_type == '#')
         {
            new_brick = (Object_Node *) malloc (sizeof (Object_Node));
            new_brick->x = column * 20;
            new_brick->y = row * 10;
            if (brick_type == '#')
            {
               new_brick->color = 10;
               new_brick->state = 0;
            }
            else
            {
               bricks++;
               new_brick->color = brick_type - '0';
               new_brick->state = 1;
               new_brick->value = (brick_type - '0') * 100;
            }
            add_node_to_dll ((DOUBLE_LIST_NODE *)*list
                            ,(DOUBLE_LIST_NODE *)new_brick);
         }
      }
   }
   fclose (file);
   return bricks;
}
