/*

    File:     init_breakout.c

    Ref. No:  breakout.1

    Author:   James Garacci

    Date:     5-APR-1995

    Purpose:

	The purpose of this module is to initialize the system colormap and
        the four pixmaps used in the program.

    Usage:

	This module can be invoked as follows:

		init_breakout ();

    Input Parameters:

	None

    Output Parameters:

	None

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include <time.h>
#include <Mrm/MrmAppl.h>
#include <X11/X.h>
#include <X11/Xutil.h>
#include <X11/Xlib.h>
#include <Xm/Text.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <Xm/FileSB.h>
#include "motif.h"
#include "motif.ext"
#include "dll.h"
#include "breakout.h"
#include "breakout.ext"

/*  Functions Referenced:

	retrieve_widget_id

**  System Calls:

	DefaultColormap
	DefaultGC
	XAllocNamedColor
	XCreatePixmap
	XFillRectangle
	XtDisplay
	XtWindow

**  Constant Definitions: **

	None

**  Macro Definitions: **

	None

**  External Variables: **

	pixmap = an array of pixmaps used for graphical output.

	program_colors = an array of structure type XColor where the colors
			 allocated for the program are stored.

**  Pseudo Code:

  Retrieve the id of the main display drawing area, instead of using the
	specified widget name
  Get the display of the widget
  Create a pixmap for displaying the player's view
  Clear the pixmap to black
  Create a pixmap for displaying the health of the player and the radar screen
  Clear the pixmap to black
  Allocate the named colors "red", "green", "blue", "yellow", and "grey32"
  Return control to the calling module

    Code:  */

void init_breakout (void)
{
   Display *display;
   Widget widget;
   XColor color;
   Dimension   wid_width, wid_height;
   int         width, height;
   int item;
   unsigned int colors [11][3] = { {     0,     0,     0 }    /* Black */
                                 , { 65535,     0,     0 }    /* Red */
                                 , {     0, 65535,     0 }    /* Green */
                                 , {     0,     0, 65535 }    /* Blue */
                                 , {     0, 65535, 65535 }    /* Turqoise */
                                 , { 65535,     0, 65535 }    /* Violet */
                                 , { 65535, 65535,     0 }    /* Yellow */
                                 , { 32767,     0,     0 }    /* Brown */
                                 , {     0, 32767,     0 }    /* Olive */
                                 , { 32767, 32767, 32767 }    /* Grey */
                                 , { 65535, 65535, 65535 } }; /* White*/

   widget = retrieve_widget_id ("display_area", 0);
   
   display = XtDisplay(widget);

   XtVaGetValues (widget
                 ,XmNwidth, &wid_width
                 ,XmNheight, &wid_height
                 ,NULL);

   width = wid_width;
   height = wid_height;

   color.flags = DoRed | DoGreen | DoBlue;

   for (item = 0
       ;item < 11
       ;item++)
   {
      color.red = colors[item][0];
      color.green = colors[item][1];
      color.blue = colors[item][2];
      program_colors[item].pixel = add_a_color (widget
                                               ,&color);
   }

   pixmap[0] = XCreatePixmap (display
                             ,(Drawable) XtWindow (widget)
                             ,width
                             ,height
                             ,DefaultDepthOfScreen(XtScreen(widget)));

   XFillRectangle (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,0
                  ,0
                  ,width
                  ,height);

   set_GC_color (program_colors[10].pixel
                ,program_colors[10].pixel
                ,display
                ,DefaultGC(display, 0));
                
   XDrawRectangle (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,0
                  ,200
                  ,width - 1
                  ,1);

   set_GC_color (program_colors[0].pixel
                ,program_colors[0].pixel
                ,display
                ,DefaultGC(display, 0));
                
   paddle_x = 0;
   paddle_y = 180;
   sound = 1;
}
