/*

    File:     init_headnode.c

    Ref. No:  dll.1

    Author:   James Garacci

    Date:     12-DEC-1993

    Purpose:

	The purpose of this module is to initialize a double linked list.

    Usage:

	This module can be invoked as follows:

           (DOUBLE_LIST_NODE *) = init_headnode();

    Input Parameters:

	None

    Output Parameters:

	(DOUBLE_LIST_NODE *) = a pointer to the initialized double linked list of
			structure type DOUBLE_LIST_NODE.

    Side Effects:

	A portion of memory has been allocated to the initialized double linked
	list and is equal to the size of the DOUBLE_LIST_NODE structure.  If the
	memory could not be allocated then the module will output an error message
	and terminate the program.

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include "dll.h"

/*  Functions Referenced:

	None

    System Calls:

	exit
	malloc
	printf
	sizeof

    External Variables:

	None

    Pseudo Code:

	Allocate memory for head node
	If the memory is not available
	   Output an error message
	   Terminate the program
	Else
	   Set FLink of head node to point at head node.
	   Set Blink of head node to point at head node.
	End If
	Return a pointer that points to the head node.

    Code:  */

DOUBLE_LIST_NODE *init_headnode (void)
{
   DOUBLE_LIST_NODE *headnode;

   if ((headnode = (DOUBLE_LIST_NODE *)malloc(sizeof(DOUBLE_LIST_NODE)))
	  == NULL)
   {
      printf("ERROR: The headnode of the double linked list could not be ");
      printf("initialized\n due to memory error.\nProgram Terminated\n");
      exit(1);
   }
   else
   {
      headnode->Flink = headnode;
      headnode->Blink = headnode;
   }
   return headnode;
}
