/*

    File:     popup_dialog.c

    Ref. No:  design.io.graphics.motif.2

    Author:   James Garacci

    Date:     06-JAN-1995

    Purpose:

	The purpose of this module is to attempt to create a dialog box.

    Usage:

	This module can be invoked as follows:

		result = popup_dialog (widget_name
                                      ,widget_index
                                      ,manage_flag);

    Input Parameters:

	widget_name = a null-terminated array of character used to specify the 
                      name of the dialog widget to be created.

	widget_index = an integer specifying the id number of the widget to be 
		    created.

	manage_flag = a Boolean used to indicate if the dialog should be managed
		      or not.

    Output Parameters:

	result = an integer used to indicate the state of the dialog.  Valid
                 values are True if the dialog was created, and False if the
                 dialog was already created.

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include <Mrm/MrmAppl.h>
#include <X11/X.h>
#include <X11/Xutil.h>
#include <X11/Xlib.h>
#include <Xm/Text.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <Xm/FileSB.h>
#include "motif.h"
#include "motif.ext"
#include "dll.h"
#include "breakout.h"
#include "breakout.ext"

/*  Functions Referenced:

	retrieve_widget_id
	save_widget_info

**  System Calls:

	exit
	MrmFetchWidget
	printf
	XtManageChild

**  Constant Definitions: **

	False
	MrmSUCCESS
	NULL
	True

**  Macro Definitions: **

	None

**  External Variables: **

	s_MrmHierarchy
	wid_top_level

**  Pseudo Code:

  Set the newly fetched indicator to False
  Attempt to retrieve the widget id
  If ( the widget was retrieved ) then
    Set the OK widget found indicator equal to 1
  Else
    Set the OK widget found indicator equal to 0
  End If
  If ( the widget was not retrieved ) then 
    Attempt to fetch the widget
    If ( the attempt was successful ) then
      Set the OK widget found indicator equal to 1
      Set the newly fetched indicator to True
      Save the information pertaining to the newly created widget
    End If
  End If
  If ( the widget was found and the calling module indicated that the widget
       should be displayed ) then
    Manage the widget
  End If
  If ( the widget was not found nor created ) then
    Output an error message
    Terminate the program
  End If
  Return the value of the newly fetched indicator to the calling module

    Code:  */

int popup_dialog ( String  widget_name
                 , int     widget_index
                 , Boolean manage_flag)
{
   Boolean new_fetch
         , ok;
   int     return_status;
   MrmType widget_class;
   Widget  widget;


   new_fetch = False;

   widget = retrieve_widget_id (widget_name
                               ,widget_index);

   ok = (widget != (Widget) NULL);
   if (!ok)
   {
      if (MrmFetchWidget (s_MrmHierarchy
                         ,widget_name
                         ,wid_top_level
                         ,&widget
                         ,&widget_class)
         == MrmSUCCESS)
      {
         ok = True;
         new_fetch = True;
         save_widget_info (widget_name
                          ,widget_index
                          ,widget);
      }
   }
   if ((ok) && (manage_flag))
      XtManageChild (widget);
   if (!ok)
   {
      printf ("popup_dialog_box: failed to fetch [%s]\n"
             ,widget_name);
      exit (1);
   }
   return (new_fetch);
}
