/*

    File:     set_gc_color.c

    Ref. No:  design.io.graphics.x.2

    Author:   James Garacci

    Date:     23-NOV-1994

    Purpose:

	The purpose of this module is to set the color of the specified
	graphics context.

    Usage:

	This module can be invoked as follows:

		set_gc_color (color
	                     ,backup_color
                             ,display
                             ,gc);

    Input Parameters:

	color = an unsigned long used to specify the pixel value of the
		foreground color to be used.
		
	backup_color = an unsigned long used to specify the pixel value of the
		       background color to be used.
	
	display = a pointer to the display that is to be referenced when
		  changing the graphics context.

	gc = a pointer to the graphics context to be changed.

    Output Parameters:

	None

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include <Mrm/MrmAppl.h>
#include <X11/X.h>
#include <X11/Xutil.h>
#include <X11/Xlib.h>
#include <Xm/Text.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <Xm/FileSB.h>

/*  Functions Referenced:

	None

**  System Calls:

	XChangeGC

**  Constant Definitions: **

	GCBackground

        GCForeground

**  Macro Definitions: **

	None

**  External Variables: **

	None

**  Pseudo Code:

  Set the forground color of the Context structure
  Set the background color of the Context structure
  Change the color of the graphics context
  Return control to the calling module

    Code:  */

void set_GC_color (unsigned long color
                  ,unsigned long backup_color
                  ,Display *display
                  ,GC *gc)
{
   XGCValues   context;

   context.foreground = color;
   context.background = backup_color;
   XChangeGC(display
            ,gc
            ,GCForeground | GCBackground
            ,&context);
}
