/*

    File:     update_display.c

    Ref. No:  breakout.2

    Author:   James Garacci

    Date:     5-APR-1995

    Purpose:

	The purpose of this module is to initialize the system colormap and
        the four pixmaps used in the program.

    Usage:

	This module can be invoked as follows:

		update_display ();

    Input Parameters:

	None

    Output Parameters:

	None

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include <time.h>
#include <Mrm/MrmAppl.h>
#include <X11/X.h>
#include <X11/Xutil.h>
#include <X11/Xlib.h>
#include <Xm/Text.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <Xm/FileSB.h>
#include "motif.h"
#include "motif.ext"
#include "dll.h"
#include "breakout.h"
#include "breakout.ext"

/*  Functions Referenced:

	retrieve_widget_id

**  System Calls:

	DefaultColormap
	DefaultGC
	XAllocNamedColor
	XCreatePixmap
	XFillRectangle
	XtDisplay
	XtWindow

**  Constant Definitions: **

	None

**  Macro Definitions: **

	None

**  External Variables: **

	pixmap = an array of pixmaps used for graphical output.

	program_colors = an array of structure type XColor where the colors
			 allocated for the program are stored.

**  Pseudo Code:

  Retrieve the id of the main display drawing area, instead of using the
	specified widget name
  Get the display of the widget


  Return control to the calling module

    Code:  */

void update_display (void)
{
   Display *display;
   Widget widget;
   Object_Node *brick;
   int count;
   int dist_x;
   int dist_y;
   char score_string [32];
   char level_string [132];

   widget = retrieve_widget_id ("display_area", 0);
   
   display = XtDisplay(widget);

   brick = (Object_Node *) brick_list->Blink;
      
   set_GC_color (program_colors[0].pixel
                ,BlackPixel(display, DefaultScreen(display))
                ,display
                ,DefaultGC(display, 0));

   XFillRectangle (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,0
                  ,0
                  ,200
                  ,200);

   while (brick != brick_list)
   {
      set_GC_color (program_colors[brick->color].pixel
                   ,WhitePixel(display, DefaultScreen(display))
                   ,display
                   ,DefaultGC(display, 0));
      XFillRectangle (display
                     ,pixmap[0]
                     ,DefaultGC(display, 0)
                     ,brick->x
                     ,brick->y
                     ,20
                     ,10);
      brick = (Object_Node *) brick->Blink;
   }

/* Check the ball coordinates against the walls to consider bouncing. */

   old_ball_x = ball_x;
   old_ball_y = ball_y;

   if (!(state))
   {
      ball_x += ball_xv;
      ball_y += ball_yv;
   
      if (ball_x < 0)
      {
         ball_x = 0;
         ball_xv = BALL_SPEED;
      }
      if (ball_x > 190 - BALL_SPEED)
      {
         ball_x = 190;
         ball_xv = -BALL_SPEED;
      }
      if (ball_y < 0)
      {
         ball_y = 0;
         ball_yv = BALL_SPEED;
      }
      if (ball_y > 190 - BALL_SPEED)
      {
         balls--;
         state = 50;
         if (!(balls < 0))
         {
            ball_x = 25 + random () % 150;
            ball_y = 100 + random () % 5;
            ball_xv = BALL_SPEED * (1 - ((random () % 2) << 1));
            ball_yv = BALL_SPEED;
         }
      }
/*  End of Walls check */

/*  Check the ball against the paddle to consider bouncing. */
      dist_x = ball_x - paddle_x;
      dist_y = paddle_y - ball_y;

      if (dist_y < 10 && dist_y > -5 )
      {
         if (dist_x > -10 && dist_x < 20)
         {
            ball_y = paddle_y - 10;
            ball_yv = -BALL_SPEED;
            if (dist_x >= 5)
            {
               ball_xv = BALL_SPEED;
            }
            else
            {
               if (dist_x <= 0)
               {
                  ball_xv = -BALL_SPEED;
               }
            }
         }
      }
/*  End of Paddle check */

/* Check the ball against the bricks. */
      brick = (Object_Node *) brick_list->Blink;
      while (brick != brick_list)
      {
         if (ball_y >= brick->y - 10 && ball_y < brick->y + 10)
         {
            if (ball_x >= brick->x && ball_x < brick->x + 20)
            {
               if (old_ball_y < brick->y + 5)
               {
                  ball_yv = -BALL_SPEED;
                  if (old_ball_x < brick->x + 3)
                  {
                     ball_xv = -BALL_SPEED;
                  }
                  else
                  {
                     if (old_ball_x > brick->x + 17)
                     {
                        ball_xv = BALL_SPEED;
                     }
                  }
               }
               else
               {
                  if (old_ball_y < brick->y + 8)
                  {
                     if (old_ball_x < brick->x + 5)
                     {
                        ball_xv = -BALL_SPEED;
                     }
                     else
                     {
                        ball_xv = BALL_SPEED;
                     }
                  }
                  else
                  {
                     ball_yv = BALL_SPEED;
                     if (old_ball_x < brick->x + 3)
                        ball_xv = -BALL_SPEED;
                     else
                        if (old_ball_x > brick->x + 17)
                           ball_xv = BALL_SPEED;
                  }
               }
               if (brick->state)
               {
                  if (sound)
                     XBell (display
                           ,-50);
                  score += brick->value;
                  if (score >= next_ball)
                  {
                     next_ball += 20000 * (( level + 1 ) / 2);
                     balls++;
                  }
                  remove_node_from_dll ((DOUBLE_LIST_NODE *) brick);
                  free (brick);
                  bricks_left--;
                  if (!bricks_left)
                  {
                     level++;
                     sprintf (level_string
                             ,"data/level.%03d"
                             ,level);
                     if (!(bricks_left = file_load_level (level_string
                                                         ,&brick_list)))
                     {
                        level = 1;
                        printf ("Exhausted available levels => level 1\n");
                        printf ("Please make more...\n");
                     }
                     sprintf (level_string
                             ,"data/level.%03d"
                             ,level);
                     if (!(bricks_left = file_load_level (level_string
                                                         ,&brick_list)))
                     {
                        printf ("(Fatal Error) Could not open data/level.001\n");
                        exit (1);
                     }
                     state = 50;
                     ball_x = 25 + random () % 150;
                     ball_y = 100 + random () % 5;
                     ball_xv = BALL_SPEED * (1 - ((random () % 2) << 1));
                     ball_yv = BALL_SPEED;
                  }
               }
               break;
            }
         }
         brick = (Object_Node *) brick->Blink;
      }
/* End of Brick Check. */
   }
/* End of State check */

   set_GC_color (program_colors[0].pixel
                ,program_colors[0].pixel
                ,display
                ,DefaultGC(display, 0));

   XFillRectangle (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,0
                  ,205
                  ,200
                  ,45);

   set_GC_color (program_colors[10].pixel
                ,program_colors[10].pixel
                ,display
                ,DefaultGC(display, 0));

   for (count = 0
       ;count < balls
       ;count++)
   {
      if (count > 4)
      {
         count = 6;
         break;
      }
      XFillArc (display
               ,pixmap[0]
               ,DefaultGC(display, 0)
               ,100 + (count % 6) * 15
               ,230
               ,10
               ,10
               ,0
               ,23040);
   }
   if (count == 6)
   {
      XFillRectangle (display
                     ,pixmap [0]
                     ,DefaultGC(display, 0)
                     ,178
                     ,230
                     ,4
                     ,10);

      XFillRectangle (display
                     ,pixmap [0]
                     ,DefaultGC(display, 0)
                     ,175
                     ,233
                     ,10
                     ,4);
   }

   sprintf (score_string
           ,"Level %d"
           ,level);
   
   XDrawString (display
               ,pixmap[0]
               ,DefaultGC(display, 0)
               ,5
               ,215
               ,score_string
               ,strlen (score_string));

   sprintf (score_string
           ,"Balls Left (%d):"
           ,(balls >= 0) ? balls : 0);
   
   XDrawString (display
               ,pixmap[0]
               ,DefaultGC(display, 0)
               ,100
               ,220
               ,score_string
               ,strlen (score_string));

   sprintf (score_string
           ,"Score:");
   
   XDrawString (display
               ,pixmap[0]
               ,DefaultGC(display, 0)
               ,5
               ,229
               ,score_string
               ,strlen (score_string));

   sprintf (score_string
           ,"%ld"
           ,score);
   
   XDrawString (display
               ,pixmap[0]
               ,DefaultGC(display, 0)
               ,5
               ,243
               ,score_string
               ,strlen (score_string));

   XFillArc (display
            ,pixmap[0]
            ,DefaultGC(display, 0)
            ,ball_x
            ,ball_y
            ,10
            ,10
            ,0
            ,23040);

   XFillRectangle (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,paddle_x
                  ,paddle_y
                  ,20
                  ,5);

   if (balls < 0 || state)
   {
      if (balls < 0)
         strcpy (score_string, "Game Over");
      else
      {
         if (state)
         {
            sprintf (score_string
                    ,"Ready %d"
                    ,state / 10);
            state--;
         }
      }
      set_GC_color (program_colors[0].pixel
                   ,program_colors[0].pixel
                   ,display
                   ,DefaultGC(display, 0));

      XFillRectangle (display
                     ,pixmap[0]
                     ,DefaultGC(display, 0)
                     ,75
                     ,100
                     ,50
                     ,20);

      set_GC_color (program_colors[10].pixel
                   ,program_colors[10].pixel
                   ,display
                   ,DefaultGC(display, 0));

      XDrawString (display
                  ,pixmap[0]
                  ,DefaultGC(display, 0)
                  ,75
                  ,105
                  ,score_string
                  ,strlen (score_string));
   }
   cb_redraw (widget
             ,&count
             ,(XmAnyCallbackStruct *) NULL);

   if (balls >= 0)
   {
      update_id = XtAppAddTimeOut (main_app_context
                                  ,50
                                  ,update_display
                                  ,(XtPointer) NULL);
   }
}
